@@ -25,7 +25,6 @@
 
 #include <KMime/Types>
 #include <QClipboard>
-#include <QSignalSpy>
 
 class RecipientsLineTestFactory : public MessageComposer::RecipientLineFactory
 {
@@ -37,7 +36,8 @@ public:
     {
     }
 
-    KPIM::MultiplyingLine *newLine(QWidget *parent) override {
+    KPIM::MultiplyingLine *newLine(QWidget *parent) override
+    {
         auto line = qobject_cast<MessageComposer::RecipientLineNG *>(
             MessageComposer::RecipientLineFactory::newLine(parent));
         line->setEnableAkonadiSearch(false);
@@ -61,7 +61,7 @@ void RecipientsEditorTest::test_addLineOnCommaPress()
     MessageComposer::RecipientsEditor editor(new RecipientsLineTestFactory());
     editor.show();
     QApplication::setActiveWindow(&editor);
-    QTest::qWaitForWindowActive(&editor);
+    QVERIFY(QTest::qWaitForWindowActive(&editor));
 
     QCOMPARE(editor.recipients().size(), 0);
 
@@ -119,7 +119,7 @@ void RecipientsEditorTest::test_splitPastedListToLines()
         QCOMPARE(editor.recipients().size(), 2);
         QCOMPARE(editor.recipients().at(0)->email(), QStringLiteral("test@example.com"));
         QCOMPARE(editor.recipients().at(1)->email(), QStringLiteral("\"Vrátil, Daniel\" <dvratil@kde.org>"));
-    }();
+    } ();
 
     clipboard->setText(oldText);
 }
