@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef RICHTEXTCOMPOSERSIGNATURES_H
-#define RICHTEXTCOMPOSERSIGNATURES_H
+#ifndef MESSAGECOMPOSER_RICHTEXTCOMPOSERSIGNATURES_H
+#define MESSAGECOMPOSER_RICHTEXTCOMPOSERSIGNATURES_H
 
 #include <QObject>
 #include "messagecomposer_export.h"
@@ -28,6 +28,10 @@ class Signature;
 
 namespace MessageComposer {
 class RichTextComposerNg;
+/**
+ * @brief The RichTextComposerSignatures class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT RichTextComposerSignatures : public QObject
 {
     Q_OBJECT
@@ -43,4 +47,4 @@ private:
     RichTextComposerSignaturesPrivate *const d;
 };
 }
-#endif // RICHTEXTCOMPOSERSIGNATURES_H
+#endif
