@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,12 +23,17 @@
 #include "messagecomposer_export.h"
 
 class QComboBox;
+class QAbstractButton;
 namespace Ui {
 class ImageScalingWidget;
 }
 
 namespace MessageComposer {
 class ImageScalingWidgetPrivate;
+/**
+ * @brief The ImageScalingWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT ImageScalingWidget : public QWidget
 {
     Q_OBJECT
@@ -50,6 +55,8 @@ private Q_SLOTS:
     void slotHelpLinkClicked(const QString &);
 
 private:
+    void slotRecipientFilterAbstractClicked(QAbstractButton *button);
+    void slotSourceFilterAbstractButtonClicked(QAbstractButton *button);
     void updateFilterSourceTypeSettings();
     void initComboBox(QComboBox *combo);
     void initWriteImageFormat();
