@@ -25,7 +25,7 @@
 
 #include "messagecomposer_export.h"
 
-#include <kjob.h>
+#include <KJob>
 
 #include <QMap>
 #include <QStringList>
