@@ -30,7 +30,6 @@
 
 class QLineEdit;
 class QActionGroup;
-class KComboBox;
 class QMenu;
 
 namespace Akonadi {
@@ -91,7 +90,7 @@ public:
     /**
     * Returns the Akonadi::MessageStatus in the current quicksearch field.
     */
-    QList<Akonadi::MessageStatus> currentFilterStatus() const;
+    QVector<Akonadi::MessageStatus> currentFilterStatus() const;
 
     /**
     * Returns the search term in the current quicksearch field.
@@ -136,7 +135,7 @@ public:
 public Q_SLOTS:
 
     /**
-    * This is called to setup the status filter's KComboBox.
+    * This is called to setup the status filter's QComboBox.
     */
     void populateStatusFilterCombo();
 
@@ -183,7 +182,7 @@ protected:
     /**
     * This is called by View when a message is right clicked.
     */
-    virtual void viewMessageListContextPopupRequest(const QList< MessageItem * > &selectedItems, const QPoint &globalPos);
+    virtual void viewMessageListContextPopupRequest(const QVector<MessageItem *> &selectedItems, const QPoint &globalPos);
 
     /**
     * This is called by View when a group header is right clicked.
@@ -224,6 +223,7 @@ Q_SIGNALS:
     * could be useful
     */
     void statusMessage(const QString &message);
+    void forceLostFocus();
 
 protected Q_SLOTS:
     /**
