@@ -20,10 +20,11 @@
 
 #include <QFile>
 
-KMime::Message::Ptr readAndParseMail(const QString &mailFile)
+KMime::Message::Ptr MessageViewer::Test::readAndParseMail(const QString &mailFile)
 {
-    QFile file(QLatin1String(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
-    Q_ASSERT(file.open(QIODevice::ReadOnly));
+    QFile file(QStringLiteral(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
+    const bool openFile = file.open(QIODevice::ReadOnly);
+    Q_ASSERT(openFile);
     const QByteArray data = KMime::CRLFtoLF(file.readAll());
     Q_ASSERT(!data.isEmpty());
     KMime::Message::Ptr msg(new KMime::Message);
