@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,6 +28,8 @@ class DKIMManagerKeyWidgetTest : public QObject
 public:
     explicit DKIMManagerKeyWidgetTest(QObject *parent = nullptr);
     ~DKIMManagerKeyWidgetTest() = default;
+private Q_SLOTS:
+    void shouldHaveDefaultValue();
 };
 
 #endif // DKIMMANAGERKEYWIDGETTEST_H
