@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,7 +18,7 @@
 */
 
 #include "dkimmanagerrules.h"
-
+#include "dkimutil.h"
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <QRegularExpression>
@@ -27,7 +27,7 @@ using namespace MessageViewer;
 DKIMManagerRules::DKIMManagerRules(QObject *parent)
     : QObject(parent)
 {
-    loadRules();
+    (void)loadRules();
 }
 
 DKIMManagerRules::~DKIMManagerRules()
@@ -49,6 +49,11 @@ void DKIMManagerRules::addRule(const DKIMRule &rule)
     }
 }
 
+bool DKIMManagerRules::isEmpty() const
+{
+    return mRules.isEmpty();
+}
+
 QVector<DKIMRule> DKIMManagerRules::rules() const
 {
     return mRules;
@@ -59,20 +64,24 @@ QStringList DKIMManagerRules::ruleGroups(const KSharedConfig::Ptr &config) const
     return config->groupList().filter(QRegularExpression(QStringLiteral("DKIM Rule #\\d+")));
 }
 
-void DKIMManagerRules::loadRules(const QString &fileName)
+int DKIMManagerRules::loadRules(const QString &fileName)
 {
-    const KSharedConfig::Ptr &config = KSharedConfig::openConfig(fileName.isEmpty() ? QStringLiteral("dkimsettingsrc") : fileName, KConfig::NoGlobals);
+    const KSharedConfig::Ptr &config = KSharedConfig::openConfig(fileName.isEmpty() ? MessageViewer::DKIMUtil::defaultConfigFileName() : fileName, KConfig::NoGlobals);
     const QStringList rulesGroups = ruleGroups(config);
 
-    mRules.clear();
+    if (fileName.isEmpty()) {
+        mRules.clear();
+    }
+    int numberOfRulesAdded = 0;
     for (const QString &groupName : rulesGroups) {
         KConfigGroup group = config->group(groupName);
-        const QStringList signedDomainIdentifier = group.readEntry(QLatin1String("SignedDomainIdentifier"), QStringList());
-        const QString from = group.readEntry(QLatin1String("From"), QString());
-        const QString domain = group.readEntry(QLatin1String("Domain"), QString());
-        const bool enabled = group.readEntry(QLatin1String("Enabled"), true);
-        const int ruleType = group.readEntry(QLatin1String("RuleType"), 0);
-        const QString listId = group.readEntry(QLatin1String("List-Id"), QString());
+        const QStringList signedDomainIdentifier = group.readEntry(QStringLiteral("SignedDomainIdentifier"), QStringList());
+        const QString from = group.readEntry(QStringLiteral("From"), QString());
+        const QString domain = group.readEntry(QStringLiteral("Domain"), QString());
+        const bool enabled = group.readEntry(QStringLiteral("Enabled"), true);
+        const int ruleType = group.readEntry(QStringLiteral("RuleType"), 0);
+        const QString listId = group.readEntry(QStringLiteral("List-Id"), QString());
+        const int priority = group.readEntry(QStringLiteral("Priority"), 1000);
         DKIMRule rule;
         rule.setEnabled(enabled);
         rule.setDomain(domain);
@@ -80,8 +89,13 @@ void DKIMManagerRules::loadRules(const QString &fileName)
         rule.setListId(listId);
         rule.setSignedDomainIdentifier(signedDomainIdentifier);
         rule.setRuleType(static_cast<DKIMRule::RuleType>(ruleType));
-        mRules.append(rule);
+        rule.setPriority(priority);
+        if (rule.isValid()) {
+            numberOfRulesAdded++;
+            mRules.append(rule);
+        }
     }
+    return numberOfRulesAdded;
 }
 
 void DKIMManagerRules::saveRules(const QVector<DKIMRule> &lst)
@@ -96,9 +110,9 @@ void DKIMManagerRules::clear()
     save();
 }
 
-void DKIMManagerRules::importRules(const QString &fileName)
+int DKIMManagerRules::importRules(const QString &fileName)
 {
-    loadRules(fileName);
+    return loadRules(fileName);
 }
 
 void DKIMManagerRules::exportRules(const QString &fileName)
@@ -108,7 +122,7 @@ void DKIMManagerRules::exportRules(const QString &fileName)
 
 void DKIMManagerRules::save(const QString &fileName)
 {
-    const KSharedConfig::Ptr &config = KSharedConfig::openConfig(fileName.isEmpty() ? QStringLiteral("dkimsettingsrc") : fileName, KConfig::NoGlobals);
+    const KSharedConfig::Ptr &config = KSharedConfig::openConfig(fileName.isEmpty() ? MessageViewer::DKIMUtil::defaultConfigFileName() : fileName, KConfig::NoGlobals);
     const QStringList rulesGroups = ruleGroups(config);
 
     for (const QString &group : rulesGroups) {
@@ -119,11 +133,12 @@ void DKIMManagerRules::save(const QString &fileName)
         KConfigGroup group = config->group(groupName);
         const DKIMRule &rule = mRules.at(i);
 
-        group.writeEntry(QLatin1String("SignedDomainIdentifier"), rule.signedDomainIdentifier());
-        group.writeEntry(QLatin1String("From"), rule.from());
-        group.writeEntry(QLatin1String("Domain"), rule.domain());
-        group.writeEntry(QLatin1String("Enabled"), rule.enabled());
-        group.writeEntry(QLatin1String("RuleType"), static_cast<int>(rule.ruleType()));
-        group.writeEntry(QLatin1String("List-Id"), rule.listId());
+        group.writeEntry(QStringLiteral("SignedDomainIdentifier"), rule.signedDomainIdentifier());
+        group.writeEntry(QStringLiteral("From"), rule.from());
+        group.writeEntry(QStringLiteral("Domain"), rule.domain());
+        group.writeEntry(QStringLiteral("Enabled"), rule.enabled());
+        group.writeEntry(QStringLiteral("RuleType"), static_cast<int>(rule.ruleType()));
+        group.writeEntry(QStringLiteral("List-Id"), rule.listId());
+        group.writeEntry(QStringLiteral("Priority"), rule.priority());
     }
 }
