@@ -17,21 +17,19 @@
    02110-1301, USA.
 */
 
-#ifndef __MESSAGEVIEWER_DEFAULTRENDERER_TEXTMESSAGEPARTRENDERER_H__
-#define __MESSAGEVIEWER_DEFAULTRENDERER_TEXTMESSAGEPARTRENDERER_H__
+#ifndef MESSAGEVIEWER_DEFAULTRENDERER_TEXTMESSAGEPARTRENDERER_H
+#define MESSAGEVIEWER_DEFAULTRENDERER_TEXTMESSAGEPARTRENDERER_H
 
 #include "../messagepartrendererbase.h"
 
-#include <QSharedPointer>
-
+namespace MessageViewer {
 class TextMessagePartRenderer : public MessagePartRendererBase
 {
 public:
     TextMessagePartRenderer();
-    virtual ~TextMessagePartRenderer();
-    QSharedPointer<PartRendered> render(MimeTreeParser::DefaultRendererPrivate *drp,
-                                        const MimeTreeParser::Interface::MessagePartPtr &msgPart)
-    const override;
+    ~TextMessagePartRenderer() override;
+    bool render(const MimeTreeParser::MessagePartPtr &msgPart, HtmlWriter *htmlWriter, RenderContext *context) const override;
 };
+}
 
 #endif
