@@ -37,15 +37,15 @@ public:
 
     ~BodyPartURLHandlerManager() override;
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 
     void registerHandler(const Interface::BodyPartURLHandler *handler, const QString &mimeType);
     void unregisterHandler(const Interface::BodyPartURLHandler *handler);
 
 private:
-    QVector<const Interface::BodyPartURLHandler *> handlersForPart(KMime::Content *node) const;
+    Q_REQUIRED_RESULT QVector<const Interface::BodyPartURLHandler *> handlersForPart(KMime::Content *node) const;
 
     typedef QHash<QByteArray, QVector<const Interface::BodyPartURLHandler *> > BodyPartHandlerList;
     BodyPartHandlerList mHandlers;
@@ -62,13 +62,13 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *) const override
     {
         return url.scheme() == QLatin1String("kmail");
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 };
 
 class MESSAGEVIEWER_TESTS_EXPORT ExpandCollapseQuoteURLManager : public MimeTreeParser::URLHandler
@@ -82,14 +82,14 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 };
 
 class MESSAGEVIEWER_TESTS_EXPORT SMimeURLHandler : public MimeTreeParser::URLHandler
@@ -103,13 +103,13 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 };
 
 class MESSAGEVIEWER_TESTS_EXPORT MailToURLHandler : public MimeTreeParser::URLHandler
@@ -123,17 +123,17 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 };
 
 class MESSAGEVIEWER_TESTS_EXPORT ContactUidURLHandler : public MimeTreeParser::URLHandler
@@ -147,9 +147,9 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 };
 
 class MESSAGEVIEWER_TESTS_EXPORT HtmlAnchorHandler : public MimeTreeParser::URLHandler
@@ -163,13 +163,13 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
         return QString();
     }
@@ -186,12 +186,12 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleShiftClick(const QUrl &, ViewerPrivate *window) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleShiftClick(const QUrl &, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 private:
     KMime::Content *nodeForUrl(const QUrl &url, ViewerPrivate *w) const;
     bool attachmentIsInHeader(const QUrl &url) const;
@@ -208,10 +208,10 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
 };
 
 // Handler that prevents dragging of internal images added by KMail, such as the envelope image
@@ -227,19 +227,19 @@ public:
     {
     }
 
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
         return QString();
     }
@@ -256,19 +256,19 @@ public:
     {
     }
 
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &url, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &url, ViewerPrivate *) const override
     {
         Q_UNUSED(url);
         return QString();
@@ -286,13 +286,13 @@ public:
     {
     }
 
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
+    Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
     {
         return false;
     }
 
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
+    Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
         return QString();
     }
