@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ using namespace MessageViewer;
 MailTrackingDetailsDialog::MailTrackingDetailsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Details"));
+    setWindowTitle(i18nc("@title:window", "Details"));
     setAttribute(Qt::WA_DeleteOnClose);
     setModal(false);
 
