@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -41,7 +41,7 @@ public:
     void hideAndClear();
 private:
     void slotShowDetails(const QString &content);
-    QString generateDetails() const;
+    Q_REQUIRED_RESULT QString generateDetails() const;
 
     struct blackListFound {
         QString url;
