@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ namespace MessageCore {
 class ImageCollector;
 }
 
-class TemplateParserExtractHtmlInfoResult;
+struct TemplateParserExtractHtmlInfoResult;
 
 namespace TemplateParser {
 class TemplateParserJobPrivate;
@@ -227,9 +227,6 @@ private:
 
     QString pipe(const QString &cmd, const QString &buf);
 
-    QString getFirstName(const QString &str);
-    QString getLastName(const QString &str);
-
     /**
      * Called by processWithTemplate(). This adds the completely processed body to
      * the message.
