@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -46,7 +46,8 @@ class WebEngineViewer::WebHitTestPrivate
 {
 public:
     WebHitTestPrivate(const QPoint &pos, const QPoint &zoomedPos)
-        : m_zoomedPos(zoomedPos), m_pos(pos)
+        : m_zoomedPos(zoomedPos)
+        , m_pos(pos)
     {
     }
 
@@ -134,4 +135,3 @@ void WebHitTest::handleHitTest(const QVariant &result)
     Q_EMIT finished(webHitResult);
     deleteLater();
 }
-
